@@ -1,12 +1,12 @@
-#ifndef NEWSBEUTER_CONFIG__H
-#define NEWSBEUTER_CONFIG__H
+#ifndef NEWSBOAT_CONFIG_H_
+#define NEWSBOAT_CONFIG_H_
 
 #define PACKAGE				"newsboat"
 #define PROGRAM_NAME			PACKAGE
-#define REAL_VERSION "2.10.1"
+#define REAL_VERSION "2.10.2"
 
 #ifdef GIT_HASH
-#define PROGRAM_VERSION			REAL_VERSION "-" GIT_HASH
+#define PROGRAM_VERSION			GIT_HASH
 #else
 #define PROGRAM_VERSION			REAL_VERSION
 #endif
@@ -36,4 +36,4 @@
 
 /* #define NDEBUG */ // only enable this #define if you want to disable all debug logging.
 
-#endif
+#endif /* NEWSBOAT_CONFIG_H_ */
