@@ -1,11 +1,11 @@
-#ifndef CONFIGCONTAINER_H_
-#define CONFIGCONTAINER_H_
+#ifndef NEWSBOAT_CONFIGCONTAINER_H_
+#define NEWSBOAT_CONFIGCONTAINER_H_
 
 #include <configparser.h>
 
 #include <unordered_set>
 
-namespace newsbeuter {
+namespace newsboat {
 
 
 enum class configdata_t { INVALID, BOOL, INT, STR, PATH, ALIAS, ENUM };
@@ -35,10 +35,10 @@ struct configdata {
 class configcontainer : public config_action_handler {
 	public:
 		configcontainer();
-		virtual ~configcontainer();
+		~configcontainer() override;
 		void register_commands(configparser& cfgparser);
-		virtual void handle_action(const std::string& action, const std::vector<std::string>& params);
-		virtual void dump_config(std::vector<std::string>& config_output);
+		void handle_action(const std::string& action, const std::vector<std::string>& params) override;
+		void dump_config(std::vector<std::string>& config_output) override;
 
 		bool get_configvalue_as_bool(const std::string& key);
 		int get_configvalue_as_int(const std::string& key);
@@ -57,4 +57,4 @@ class configcontainer : public config_action_handler {
 
 }
 
-#endif /*CONFIGCONTAINER_H_*/
+#endif /* NEWSBOAT_CONFIGCONTAINER_H_ */
