@@ -1,9 +1,9 @@
-#ifndef PODBEUTER_DOWNLOAD__H
-#define PODBEUTER_DOWNLOAD__H
+#ifndef PODBOAT_DOWNLOAD_H_
+#define PODBOAT_DOWNLOAD_H_
 
 #include <string>
 
-namespace podbeuter {
+namespace podboat {
 
 enum class dlstatus {
 	QUEUED = 0,
@@ -25,7 +25,7 @@ class download {
 		~download();
 		double percents_finished();
 		const std::string status_text();
-		inline dlstatus status() const {
+		dlstatus status() const {
 			return download_status;
 		}
 		const std::string filename();
@@ -38,10 +38,10 @@ class download {
 		double kbps();
 		void set_offset(unsigned long offset);
 
-		inline double current_size() const {
+		double current_size() const {
 			return cursize + offs;
 		}
-		inline double total_size() const {
+		double total_size() const {
 			return totalsize + offs;
 		}
 
@@ -58,4 +58,4 @@ class download {
 
 }
 
-#endif
+#endif /* PODBOAT_DOWNLOAD_H_ */
