@@ -1,5 +1,5 @@
-#ifndef NEWSBEUTER_KEYMAP__H
-#define NEWSBEUTER_KEYMAP__H
+#ifndef NEWSBOAT_KEYMAP_H_
+#define NEWSBOAT_KEYMAP_H_
 
 #include <string>
 #include <map>
@@ -10,7 +10,6 @@
 
 // in configuration: bind-key <key> <operation>
 
-
 enum {
 	KM_FEEDLIST		= 1<<0,
 	KM_FILEBROWSER	= 1<<1,
@@ -20,15 +19,15 @@ enum {
 	KM_TAGSELECT	= 1<<5,
 	KM_FILTERSELECT	= 1<<6,
 	KM_URLVIEW		= 1<<7,
-	KM_PODBEUTER	= 1<<8,
+	KM_PODBOAT		= 1<<8,
 	KM_SYSKEYS		= 1<<9,
 	KM_INTERNAL		= 1<<10,
 	KM_DIALOGS		= 1<<11,
-	KM_NEWSBEUTER	= KM_FEEDLIST | KM_FILEBROWSER | KM_HELP | KM_ARTICLELIST | KM_ARTICLE | KM_TAGSELECT | KM_FILTERSELECT | KM_URLVIEW | KM_DIALOGS,
-	KM_BOTH			= KM_NEWSBEUTER | KM_PODBEUTER
+	KM_NEWSBOAT 	= KM_FEEDLIST | KM_FILEBROWSER | KM_HELP | KM_ARTICLELIST | KM_ARTICLE | KM_TAGSELECT | KM_FILTERSELECT | KM_URLVIEW | KM_DIALOGS,
+	KM_BOTH			= KM_NEWSBOAT | KM_PODBOAT
 };
 
-namespace newsbeuter {
+namespace newsboat {
 
 enum operation {	OP_NIL = 0,
                     // general and newsboat-specific operations:
@@ -85,7 +84,7 @@ enum operation {	OP_NIL = 0,
                     OP_REVSORT,
                     OP_NB_MAX,
 
-                    // podbeuter-specific operations:
+                    // podboat-specific operations:
                     OP_PB_MIN = 1000,
                     OP_PB_DOWNLOAD,
                     OP_PB_CANCEL,
@@ -156,7 +155,7 @@ struct macrocmd {
 class keymap : public config_action_handler {
 	public:
 		explicit keymap(unsigned int flags);
-		~keymap();
+		~keymap() override;
 		void set_key(operation op, const std::string& key, const std::string& context);
 		void unset_key(const std::string& key, const std::string& context);
 		operation get_opcode(const std::string& opstr);
@@ -164,8 +163,8 @@ class keymap : public config_action_handler {
 		std::vector<macrocmd> get_macro(const std::string& key);
 		char get_key(const std::string& keycode);
 		std::string getkey(operation op, const std::string& context);
-		virtual void handle_action(const std::string& action, const std::vector<std::string>& params);
-		virtual void dump_config(std::vector<std::string>& config_output);
+		void handle_action(const std::string& action, const std::vector<std::string>& params) override;
+		void dump_config(std::vector<std::string>& config_output) override;
 		void get_keymap_descriptions(std::vector<keymap_desc>& descs, unsigned short flags);
 		unsigned short get_flag_from_context(const std::string& context);
 	private:
@@ -177,5 +176,4 @@ class keymap : public config_action_handler {
 
 }
 
-
-#endif
+#endif /* NEWSBOAT_KEYMAP_H_ */
