@@ -1,5 +1,5 @@
-#ifndef NEWSBEUTER_NEWSBLUR_API__H
-#define NEWSBEUTER_NEWSBLUR_API__H
+#ifndef NEWSBOAT_NEWSBLUR_API_H_
+#define NEWSBOAT_NEWSBLUR_API_H_
 
 #include <remote_api.h>
 #include <urlreader.h>
@@ -8,20 +8,20 @@
 
 #define ID_SEPARATOR "/////"
 
-namespace newsbeuter {
+namespace newsboat {
 
 typedef std::map<std::string, rsspp::feed> feedmap;
 
 class newsblur_api : public remote_api {
 	public:
 		explicit newsblur_api(configcontainer * c);
-		virtual ~newsblur_api();
-		virtual bool authenticate();
-		virtual std::vector<tagged_feedurl> get_subscribed_urls();
-		virtual void add_custom_headers(curl_slist** custom_headers);
-		virtual bool mark_all_read(const std::string& feedurl);
-		virtual bool mark_article_read(const std::string& guid, bool read);
-		virtual bool update_article_flags(const std::string& oldflags, const std::string& newflags, const std::string& guid);
+		~newsblur_api() override;
+		bool authenticate() override;
+		std::vector<tagged_feedurl> get_subscribed_urls() override;
+		void add_custom_headers(curl_slist** custom_headers) override;
+		bool mark_all_read(const std::string& feedurl) override;
+		bool mark_article_read(const std::string& guid, bool read) override;
+		bool update_article_flags(const std::string& oldflags, const std::string& newflags, const std::string& guid) override;
 		rsspp::feed fetch_feed(const std::string& id);
 		// TODO
 	private:
@@ -37,10 +37,10 @@ class newsblur_api : public remote_api {
 class newsblur_urlreader : public urlreader {
 	public:
 		newsblur_urlreader(const std::string& url_file, remote_api * a);
-		virtual ~newsblur_urlreader();
-		virtual void write_config();
-		virtual void reload();
-		virtual std::string get_source();
+		~newsblur_urlreader() override;
+		void write_config() override;
+		void reload() override;
+		std::string get_source() override;
 	private:
 		std::string file;
 		remote_api * api;
@@ -48,4 +48,4 @@ class newsblur_urlreader : public urlreader {
 
 }
 
-#endif
+#endif /* NEWSBOAT_NEWSBLUR_API_H_ */
