@@ -1,5 +1,5 @@
-#ifndef OCNEWS_API_H
-#define OCNEWS_API_H
+#ifndef NEWSBOAT_OCNEWS_API_H_
+#define NEWSBOAT_OCNEWS_API_H_
 
 #include <map>
 
@@ -9,18 +9,18 @@
 #include <urlreader.h>
 #include <rsspp.h>
 
-namespace newsbeuter {
+namespace newsboat {
 
 class ocnews_api : public remote_api {
 	public:
 		explicit ocnews_api (configcontainer *cfg);
-		virtual ~ocnews_api();
-		virtual bool authenticate();
-		virtual std::vector<tagged_feedurl> get_subscribed_urls();
-		virtual bool mark_all_read(const std::string& feedurl);
-		virtual bool mark_article_read(const std::string& guid, bool read);
-		virtual bool update_article_flags(const std::string& oldflags, const std::string& newflags, const std::string& guid);
-		virtual void add_custom_headers(curl_slist**);
+		~ocnews_api() override;
+		bool authenticate() override;
+		std::vector<tagged_feedurl> get_subscribed_urls() override;
+		bool mark_all_read(const std::string& feedurl) override;
+		bool mark_article_read(const std::string& guid, bool read) override;
+		bool update_article_flags(const std::string& oldflags, const std::string& newflags, const std::string& guid) override;
+		void add_custom_headers(curl_slist**) override;
 		rsspp::feed fetch_feed(const std::string& feed_id);
 	private:
 		typedef std::map<std::string, std::pair<rsspp::feed, long>> feedmap;
@@ -35,10 +35,10 @@ class ocnews_api : public remote_api {
 class ocnews_urlreader : public urlreader {
 	public:
 		ocnews_urlreader(const std::string& url_file, remote_api * a);
-		virtual ~ocnews_urlreader();
-		virtual void write_config();
-		virtual void reload();
-		virtual std::string get_source();
+		~ocnews_urlreader() override;
+		void write_config() override;
+		void reload() override;
+		std::string get_source() override;
 	private:
 		std::string file;
 		remote_api * api;
@@ -46,4 +46,4 @@ class ocnews_urlreader : public urlreader {
 
 }
 
-#endif // OCNEWS_API_H
+#endif /* NEWSBOAT_OCNEWS_API_H_ */
