@@ -1,11 +1,11 @@
-#ifndef tagsouppullparser_H_
-#define tagsouppullparser_H_
+#ifndef NEWSBOAT_TAGSOUPPULLPARSER_H_
+#define NEWSBOAT_TAGSOUPPULLPARSER_H_
 
 #include <string>
 #include <utility>
 #include <vector>
 
-namespace newsbeuter {
+namespace newsboat {
 
 class tagsouppullparser {
 	public:
@@ -45,4 +45,4 @@ class tagsouppullparser {
 
 }
 
-#endif /*tagsouppullparser_H_*/
+#endif /* NEWSBOAT_TAGSOUPPULLPARSER_H_ */
