@@ -1,5 +1,5 @@
-#ifndef UTIL_H_
-#define UTIL_H_
+#ifndef NEWSBOAT_UTIL_H_
+#define NEWSBOAT_UTIL_H_
 
 #include <vector>
 #include <string>
@@ -11,7 +11,7 @@
 #include <configcontainer.h>
 #include <libxml/parser.h>
 
-namespace newsbeuter {
+namespace newsboat {
 
 // wrapped curl handle for exception safety and so on
 // see also: https://github.com/gsauthof/ccurl
@@ -46,9 +46,6 @@ class utils {
 
 		static std::vector<std::wstring> wtokenize(const std::wstring& str, std::wstring delimiters = L" \r\n\t");
 
-		static bool try_fs_lock(const std::string& lock_file, pid_t & pid);
-		static void remove_fs_lock(const std::string& lock_file);
-
 		static std::string translit(const std::string& tocode, const std::string& fromcode);
 		static std::string convert_text(const std::string& text, const std::string& tocode, const std::string& fromcode);
 
@@ -80,11 +77,13 @@ class utils {
 		static size_t strwidth_stfl(const std::string& str);
 		static size_t wcswidth_stfl(const std::wstring& str, size_t size);
 
-		static inline unsigned int max(unsigned int a, unsigned int b) {
+		static std::string substr_with_width(const std::string& str, const size_t max_width);
+
+		static unsigned int max(unsigned int a, unsigned int b) {
 			return (a > b) ? a : b;
 		}
 
-		static inline unsigned int to_u(const std::string& str) {
+		static unsigned int to_u(const std::string& str) {
 			return to_u(str, 0);
 		}
 		static unsigned int to_u(
@@ -141,6 +140,8 @@ class utils {
 
 		static void remove_soft_hyphens(std::string& text);
 
+		static bool is_valid_podcast_type(const std::string& mimetype);
+
 	private:
 		static void append_escapes(std::string& str, char c);
 
@@ -159,4 +160,4 @@ class scope_measure {
 
 }
 
-#endif /*UTIL_H_*/
+#endif /* NEWSBOAT_UTIL_H_ */
