@@ -1,8 +1,3 @@
-/* rsspp - Copyright (C) 2008-2012 Andreas Krennmair <ak@newsbeuter.org>
- * Licensed under the MIT/X Consortium License. See file LICENSE
- * for more information.
- */
-
 #include <config.h>
 #include <rsspp.h>
 #include <rsspp_internal.h>
@@ -16,7 +11,7 @@
 #include <strprintf.h>
 #include <remote_api.h>
 
-using namespace newsbeuter;
+using namespace newsboat;
 
 static size_t my_write_data(void *buffer, size_t size, size_t nmemb, void *userp) {
 	std::string * pbuf = static_cast<std::string *>(userp);
@@ -77,7 +72,7 @@ static size_t handle_headers(void * ptr, size_t size, size_t nmemb, void * data)
 	return size * nmemb;
 }
 
-feed parser::parse_url(const std::string& url, time_t lastmodified, const std::string& etag, newsbeuter::remote_api * api, const std::string& cookie_cache, CURL *ehandle) {
+feed parser::parse_url(const std::string& url, time_t lastmodified, const std::string& etag, newsboat::remote_api * api, const std::string& cookie_cache, CURL *ehandle) {
 	std::string buf;
 	CURLcode ret;
 	curl_slist* custom_headers {};
@@ -161,6 +156,9 @@ feed parser::parse_url(const std::string& url, time_t lastmodified, const std::s
 	CURLcode infoOk = curl_easy_getinfo(easyhandle, CURLINFO_RESPONSE_CODE, &status);
 
 	curl_easy_reset(easyhandle);
+	if (cookie_cache != "") {
+		curl_easy_setopt(easyhandle, CURLOPT_COOKIEJAR, cookie_cache.c_str());
+	}
 
 	if (!ehandle)
 		curl_easy_cleanup(easyhandle);
