@@ -20,6 +20,7 @@
 #include <ttrss_api.h>
 #include <newsblur_api.h>
 #include <ocnews_api.h>
+#include <inoreader_api.h>
 #include <xlicense.h>
 
 #include <cstdlib>
@@ -55,23 +56,21 @@
 #include <libxml/uri.h>
 #include <curl/curl.h>
 
-namespace newsbeuter {
+namespace newsboat {
 
-#define LOCK_SUFFIX ".lock"
-
-std::string lock_file;
+const std::string controller::LOCK_SUFFIX = ".lock";
 
 int ctrl_c_hit = 0;
 
-void ctrl_c_action(int sig) {
-	LOG(level::DEBUG,"caught signal %d",sig);
-	if (SIGINT == sig) {
-		ctrl_c_hit = 1;
-	} else {
-		stfl::reset();
-		utils::remove_fs_lock(lock_file);
-		::exit(EXIT_FAILURE);
-	}
+void ctrl_c_action(int /* sig */) {
+	LOG(level::DEBUG, "caught SIGINT");
+	ctrl_c_hit = 1;
+}
+
+void sighup_action(int /* sig */) {
+	LOG(level::DEBUG, "caught SIGHUP");
+	stfl::reset();
+	::exit(EXIT_FAILURE);
 }
 
 void ignore_signal(int sig) {
@@ -94,7 +93,7 @@ controller::controller() : v(0), urlcfg(0), rsscache(0), url_file("urls"), cache
  *
  * returns false, if that fails
  */
-bool controller::setup_dirs_xdg(const char *env_home) {
+bool controller::setup_dirs_xdg(const std::string& env_home) {
 	const char *env_xdg_config;
 	const char *env_xdg_data;
 	std::string xdg_config_dir;
@@ -125,7 +124,6 @@ bool controller::setup_dirs_xdg(const char *env_home) {
 
 	xdg_data_dir.append(NEWSBEUTER_PATH_SEP);
 	xdg_data_dir.append(NEWSBOAT_SUBDIR_XDG);
-	data_dir = xdg_data_dir;
 
 	bool config_dir_exists = 0 == access(xdg_config_dir.c_str(), R_OK | X_OK);
 
@@ -139,6 +137,7 @@ bool controller::setup_dirs_xdg(const char *env_home) {
 	 * data dir exists, because if it doesn't we'll create it. */
 
 	config_dir = xdg_config_dir;
+	data_dir = xdg_data_dir;
 
 	/* in config */
 	url_file = config_dir + std::string(NEWSBEUTER_PATH_SEP) + url_file;
@@ -154,19 +153,7 @@ bool controller::setup_dirs_xdg(const char *env_home) {
 	return true;
 }
 
-void controller::setup_dirs() {
-	const char * env_home;
-	if (!(env_home = ::getenv("HOME"))) {
-		struct passwd * spw = ::getpwuid(::getuid());
-		if (spw) {
-			env_home = spw->pw_dir;
-		} else {
-			std::cerr << _("Fatal error: couldn't determine home directory!") << std::endl;
-			std::cerr << strprintf::fmt(_("Please set the HOME environment variable or add a valid user for UID %u!"), ::getuid()) << std::endl;
-			::exit(EXIT_FAILURE);
-		}
-	}
-
+void controller::setup_dirs(const std::string& env_home) {
 	config_dir = env_home;
 	config_dir.append(NEWSBEUTER_PATH_SEP);
 	config_dir.append(NEWSBOAT_CONFIG_SUBDIR);
@@ -195,7 +182,10 @@ void copy_file(
 	dst << src.rdbuf();
 }
 
-bool controller::migrate_data_from_newsbeuter_xdg(const char* env_home, bool silent) {
+bool controller::migrate_data_from_newsbeuter_xdg(
+		const std::string& env_home,
+		bool silent)
+{
 	const char* env_xdg_config = ::getenv("XDG_CONFIG_HOME");
 	std::string xdg_config_dir;
 	if (env_xdg_config) {
@@ -227,7 +217,6 @@ bool controller::migrate_data_from_newsbeuter_xdg(const char* env_home, bool sil
 		= xdg_config_dir + NEWSBEUTER_PATH_SEP + NEWSBOAT_SUBDIR_XDG + NEWSBEUTER_PATH_SEP;
 	const auto newsboat_data_dir
 		= xdg_data_dir + NEWSBEUTER_PATH_SEP + NEWSBOAT_SUBDIR_XDG + NEWSBEUTER_PATH_SEP;
-	data_dir = newsboat_data_dir;
 
 	bool newsbeuter_config_dir_exists = 0 == access(newsbeuter_config_dir.c_str(), R_OK | X_OK);
 
@@ -235,7 +224,7 @@ bool controller::migrate_data_from_newsbeuter_xdg(const char* env_home, bool sil
 		return false;
 	}
 
-	auto exists = [silent](const std::string& dir) -> bool {
+	auto exists = [](const std::string& dir) -> bool {
 		bool dir_exists = 0 == access(dir.c_str(), F_OK);
 		if (dir_exists) {
 			LOG(level::DEBUG, "%s already exists, aborting XDG migration.", dir);
@@ -248,6 +237,8 @@ bool controller::migrate_data_from_newsbeuter_xdg(const char* env_home, bool sil
 	if (exists(newsboat_data_dir)) {
 		return false;
 	}
+	config_dir = newsboat_config_dir;
+	data_dir = newsboat_data_dir;
 
 	if (! silent) {
 		std::cerr
@@ -255,7 +246,7 @@ bool controller::migrate_data_from_newsbeuter_xdg(const char* env_home, bool sil
 			<< std::endl;
 	}
 
-	auto try_mkdir = [silent](const std::string& dir) -> bool{
+	auto try_mkdir = [](const std::string& dir) -> bool {
 		bool result = 0 == utils::mkdir_parents(dir, 0700);
 		if (! result) {
 			LOG(level::DEBUG,
@@ -284,7 +275,10 @@ bool controller::migrate_data_from_newsbeuter_xdg(const char* env_home, bool sil
 	return true;
 }
 
-bool controller::migrate_data_from_newsbeuter_simple(const char* env_home, bool silent) {
+bool controller::migrate_data_from_newsbeuter_simple(
+		const std::string& env_home,
+		bool silent)
+{
 	std::string newsbeuter_dir = env_home;
 	newsbeuter_dir += NEWSBEUTER_PATH_SEP;
 	newsbeuter_dir += NEWSBEUTER_CONFIG_SUBDIR;
@@ -334,19 +328,10 @@ bool controller::migrate_data_from_newsbeuter_simple(const char* env_home, bool
 	return true;
 }
 
-void controller::migrate_data_from_newsbeuter(bool silent) {
-	const char * env_home;
-	if (!(env_home = ::getenv("HOME"))) {
-		struct passwd * spw = ::getpwuid(::getuid());
-		if (spw) {
-			env_home = spw->pw_dir;
-		} else {
-			std::cerr << _("Fatal error: couldn't determine home directory!") << std::endl;
-			std::cerr << strprintf::fmt(_("Please set the HOME environment variable or add a valid user for UID %u!"), ::getuid()) << std::endl;
-			::exit(EXIT_FAILURE);
-		}
-	}
-
+void controller::migrate_data_from_newsbeuter(
+		const std::string& env_home,
+		bool silent)
+{
 	bool migrated = migrate_data_from_newsbeuter_xdg(env_home, silent);
 
 	if (migrated) {
@@ -355,7 +340,7 @@ void controller::migrate_data_from_newsbeuter(bool silent) {
 		cache_file = "cache.db";
 		config_file = "config";
 		queue_file = "queue";
-		setup_dirs();
+		setup_dirs(env_home);
 	} else {
 		migrated = migrate_data_from_newsbeuter_simple(env_home, silent);
 	}
@@ -383,12 +368,12 @@ void controller::set_view(view * vv) {
 	v = vv;
 }
 
-void controller::run(int argc, char * argv[]) {
+int controller::run(int argc, char * argv[]) {
 	int c;
 
 	::signal(SIGINT, ctrl_c_action);
 	::signal(SIGPIPE, ignore_signal);
-	::signal(SIGHUP, ctrl_c_action);
+	::signal(SIGHUP, sighup_action);
 	::signal(SIGCHLD, omg_a_child_died);
 
 	bool do_import = false, do_export = false, cachefile_given_on_cmdline = false, do_vacuum = false;
@@ -420,16 +405,19 @@ void controller::run(int argc, char * argv[]) {
 		{0                 , 0                , 0,  0 }
 	};
 
-	/* First of all, let's check for options that imply silencing of the
-	 * output: import, export, command execution and, well, quiet mode */
-	while ((c = ::getopt_long(argc, argv, getopt_str, longopts, nullptr)) != -1) {
-		if (strchr("iexq", c) != nullptr) {
-			silent = true;
-			break;
+	const char * env_home;
+	if (!(env_home = ::getenv("HOME"))) {
+		struct passwd * spw = ::getpwuid(::getuid());
+		if (spw) {
+			env_home = spw->pw_dir;
+		} else {
+			std::cerr << _("Fatal error: couldn't determine home directory!") << std::endl;
+			std::cerr << strprintf::fmt(_("Please set the HOME environment variable or add a valid user for UID %u!"), ::getuid()) << std::endl;
+			return EXIT_FAILURE;
 		}
 	}
 
-	setup_dirs();
+	setup_dirs(env_home);
 
 	bool using_nonstandard_configs = false;
 
@@ -441,11 +429,13 @@ void controller::run(int argc, char * argv[]) {
 		switch (c) {
 		case ':': /* fall-through */
 		case '?': /* missing option */
-			usage(argv[0]);
-			break;
+			print_usage(argv[0]);
+			return EXIT_FAILURE;
 		case 'i':
-			if (do_export)
-				usage(argv[0]);
+			if (do_export) {
+				print_usage(argv[0]);
+				return EXIT_FAILURE;
+			}
 			do_import = true;
 			importfile = optarg;
 			break;
@@ -453,13 +443,18 @@ void controller::run(int argc, char * argv[]) {
 			refresh_on_start = true;
 			break;
 		case 'e':
-			if (do_import)
-				usage(argv[0]);
+			// disable logging of newsboat's startup progress to stdout, because the
+			// OPML export will be printed to stdout
+			silent = true;
+			if (do_import) {
+				print_usage(argv[0]);
+				return EXIT_FAILURE;
+			}
 			do_export = true;
 			break;
 		case 'h':
-			usage(argv[0]);
-			break;
+			print_usage(argv[0]);
+			return EXIT_SUCCESS;
 		case 'u':
 			url_file = optarg;
 			using_nonstandard_configs = true;
@@ -482,9 +477,13 @@ void controller::run(int argc, char * argv[]) {
 			show_version++;
 			break;
 		case 'x':
+			// disable logging of newsboat's startup progress to stdout, because the
+			// command execution result will be printed to stdout
+			silent = true;
 			execute_cmds = true;
 			break;
 		case 'q':
+			silent = true;
 			break;
 		case 'd':
 			logger::getInstance().set_logfile(optarg);
@@ -495,32 +494,37 @@ void controller::run(int argc, char * argv[]) {
 				logger::getInstance().set_loglevel(l);
 			} else {
 				std::cerr << strprintf::fmt(_("%s: %d: invalid loglevel value"), argv[0], l) << std::endl;
-				::std::exit(EXIT_FAILURE);
+				return EXIT_FAILURE;
 			}
 		}
 		break;
 		case 'I':
-			if (do_read_export)
-				usage(argv[0]);
+			if (do_read_export) {
+				print_usage(argv[0]);
+				return EXIT_FAILURE;
+			}
 			do_read_import = true;
 			readinfofile = optarg;
 			break;
 		case 'E':
-			if (do_read_import)
-				usage(argv[0]);
+			if (do_read_import) {
+				print_usage(argv[0]);
+				return EXIT_FAILURE;
+			}
 			do_read_export = true;
 			readinfofile = optarg;
 			break;
 		default:
 			std::cout << strprintf::fmt(_("%s: unknown option - %c"), argv[0], static_cast<char>(c)) << std::endl;
-			usage(argv[0]);
-			break;
+			print_usage(argv[0]);
+			return EXIT_FAILURE;
 		}
 	};
 
 
 	if (show_version) {
-		version_information(argv[0], show_version);
+		print_version_information(argv[0], show_version);
+		return EXIT_SUCCESS;
 	}
 
 	if (do_import) {
@@ -528,14 +532,14 @@ void controller::run(int argc, char * argv[]) {
 		urlcfg = new file_urlreader(url_file);
 		urlcfg->reload();
 		import_opml(importfile);
-		return;
+		return EXIT_SUCCESS;
 	}
 
 
 	LOG(level::INFO, "nl_langinfo(CODESET): %s", nl_langinfo(CODESET));
 
 	if ((! using_nonstandard_configs) && (0 != access(url_file.c_str(), F_OK))) {
-		migrate_data_from_newsbeuter(silent);
+		migrate_data_from_newsbeuter(env_home, silent);
 	}
 
 	utils::mkdir_parents(config_dir.c_str(), 0700);
@@ -546,17 +550,13 @@ void controller::run(int argc, char * argv[]) {
 		if (!silent)
 			std::cout << strprintf::fmt(_("Starting %s %s..."), PROGRAM_NAME, PROGRAM_VERSION) << std::endl;
 
+		fslock = std::unique_ptr<FSLock>(new FSLock());
 		pid_t pid;
-		if (!utils::try_fs_lock(lock_file, pid)) {
-			if (pid > 0) {
-				LOG(level::ERROR,"an instance is already running: pid = %u",pid);
-			} else {
-				LOG(level::ERROR,"something went wrong with the lock: %s", strerror(errno));
-			}
+		if (! fslock->try_lock(lock_file, pid)) {
 			if (!execute_cmds) {
 				std::cout << strprintf::fmt(_("Error: an instance of %s is already running (PID: %u)"), PROGRAM_NAME, pid) << std::endl;
 			}
-			return;
+			return EXIT_FAILURE;
 		}
 	}
 
@@ -567,7 +567,7 @@ void controller::run(int argc, char * argv[]) {
 	cfg.register_commands(cfgparser);
 	colorman.register_commands(cfgparser);
 
-	keymap keys(KM_NEWSBEUTER);
+	keymap keys(KM_NEWSBOAT);
 	cfgparser.register_handler("bind-key",&keys);
 	cfgparser.register_handler("unbind-key",&keys);
 	cfgparser.register_handler("macro", &keys);
@@ -586,8 +586,7 @@ void controller::run(int argc, char * argv[]) {
 	} catch (const configexception& ex) {
 		LOG(level::ERROR,"an exception occurred while parsing the configuration file: %s",ex.what());
 		std::cout << ex.what() << std::endl;
-		utils::remove_fs_lock(lock_file);
-		return;
+		return EXIT_FAILURE;
 	}
 
 	update_config();
@@ -600,21 +599,12 @@ void controller::run(int argc, char * argv[]) {
 	if (cachefilepath.length() > 0 && !cachefile_given_on_cmdline) {
 		cache_file = cachefilepath.c_str();
 
-		// ok, we got another cache file path via the configuration
-		// that means we need to remove the old lock file, assemble
-		// the new lock file's name, and then try to lock it.
-		utils::remove_fs_lock(lock_file);
 		lock_file = std::string(cache_file) + LOCK_SUFFIX;
-
+		fslock = std::unique_ptr<FSLock>(new FSLock());
 		pid_t pid;
-		if (!utils::try_fs_lock(lock_file, pid)) {
-			if (pid > 0) {
-				LOG(level::ERROR,"an instance is already running: pid = %u",pid);
-			} else {
-				LOG(level::ERROR,"something went wrong with the lock: %s", strerror(errno));
-			}
+		if (! fslock->try_lock(lock_file, pid)) {
 			std::cout << strprintf::fmt(_("Error: an instance of %s is already running (PID: %u)"), PROGRAM_NAME, pid) << std::endl;
-			return;
+			return EXIT_FAILURE;
 		}
 	}
 
@@ -626,8 +616,7 @@ void controller::run(int argc, char * argv[]) {
 		rsscache = new cache(cache_file,&cfg);
 	} catch (const dbexception& e) {
 		std::cerr << strprintf::fmt(_("Error: opening the cache file `%s' failed: %s"), cache_file, e.what()) << std::endl;
-		utils::remove_fs_lock(lock_file);
-		::exit(EXIT_FAILURE);
+		return EXIT_FAILURE;
 	}
 
 	if (!silent) {
@@ -648,6 +637,14 @@ void controller::run(int argc, char * argv[]) {
 		api = new ttrss_api(&cfg);
 		urlcfg = new ttrss_urlreader(url_file, api);
 	} else if (type == "newsblur") {
+		auto cookies = cfg.get_configvalue("cookie-cache");
+		std::ofstream check(cookies);
+		if (! check.is_open()) {
+			std::cout << strprintf::fmt(
+					_("%s is inaccessible and can't be created\n"), cookies);
+			return EXIT_FAILURE;
+		}
+
 		api = new newsblur_api(&cfg);
 		urlcfg = new newsblur_urlreader(url_file, api);
 	} else if (type == "feedhq") {
@@ -656,6 +653,9 @@ void controller::run(int argc, char * argv[]) {
 	} else if (type == "ocnews") {
 		api = new ocnews_api(&cfg);
 		urlcfg = new ocnews_urlreader(url_file, api);
+	} else if (type == "inoreader") {
+		api = new inoreader_api(&cfg);
+		urlcfg = new inoreader_urlreader(&cfg, url_file, api);
 	} else {
 		LOG(level::ERROR,"unknown urls-source `%s'", urlcfg->get_source());
 	}
@@ -667,8 +667,7 @@ void controller::run(int argc, char * argv[]) {
 	if (api) {
 		if (!api->authenticate()) {
 			std::cout << "Authentication failed." << std::endl;
-			utils::remove_fs_lock(lock_file);
-			return;
+			return EXIT_FAILURE;
 		}
 	}
 	urlcfg->reload();
@@ -689,11 +688,14 @@ void controller::run(int argc, char * argv[]) {
 			msg = strprintf::fmt(_("It looks like you haven't configured any feeds in your Tiny Tiny RSS account. Please do so, and try again."));
 		} else if (type == "newsblur") {
 			msg = strprintf::fmt(_("It looks like you haven't configured any feeds in your NewsBlur account. Please do so, and try again."));
+		} else if (type == "inoreader") {
+			msg = strprintf::fmt(_("It looks like you haven't configured any feeds in your Inoreader account. Please do so, and try again."));
 		} else {
 			assert(0); // shouldn't happen
 		}
 		std::cout << msg << std::endl << std::endl;
-		usage(argv[0]);
+		print_usage(argv[0]);
+		return EXIT_FAILURE;
 	}
 
 	if (!do_export && !do_vacuum && !silent)
@@ -709,8 +711,7 @@ void controller::run(int argc, char * argv[]) {
 		std::cout.flush();
 		rsscache->do_vacuum();
 		std::cout << _("done.") << std::endl;
-		utils::remove_fs_lock(lock_file);
-		return;
+		return EXIT_SUCCESS;
 	}
 
 	unsigned int i=0;
@@ -724,12 +725,10 @@ void controller::run(int argc, char * argv[]) {
 			feeds.push_back(feed);
 		} catch(const dbexception& e) {
 			std::cout << _("Error while loading feeds from database: ") << e.what() << std::endl;
-			utils::remove_fs_lock(lock_file);
-			return;
+			return EXIT_FAILURE;
 		} catch(const std::string& str) {
 			std::cout << strprintf::fmt(_("Error while loading feed '%s': %s"), url, str) << std::endl;
-			utils::remove_fs_lock(lock_file);
-			return;
+			return EXIT_FAILURE;
 		}
 		i++;
 	}
@@ -756,8 +755,7 @@ void controller::run(int argc, char * argv[]) {
 
 	if (do_export) {
 		export_opml();
-		utils::remove_fs_lock(lock_file);
-		return;
+		return EXIT_SUCCESS;
 	}
 
 	if (do_read_import) {
@@ -766,7 +764,7 @@ void controller::run(int argc, char * argv[]) {
 		std::cout.flush();
 		import_read_information(readinfofile);
 		std::cout << _("done.") << std::endl;
-		return;
+		return EXIT_SUCCESS;
 	}
 
 	if (do_read_export) {
@@ -775,7 +773,7 @@ void controller::run(int argc, char * argv[]) {
 		std::cout.flush();
 		export_read_information(readinfofile);
 		std::cout << _("done.") << std::endl;
-		return;
+		return EXIT_SUCCESS;
 	}
 
 	// hand over the important objects to the view
@@ -785,8 +783,7 @@ void controller::run(int argc, char * argv[]) {
 
 	if (execute_cmds) {
 		execute_commands(argv, optind);
-		utils::remove_fs_lock(lock_file);
-		return;
+		return EXIT_SUCCESS;
 	}
 
 	// if the user wants to refresh on startup via configuration file, then do so,
@@ -798,7 +795,7 @@ void controller::run(int argc, char * argv[]) {
 	formaction::load_histories(searchfile, cmdlinefile);
 
 	// run the view
-	v->run();
+	int ret = v->run();
 
 	unsigned int history_limit = cfg.get_configvalue_as_int("history-limit");
 	LOG(level::DEBUG, "controller::run: history-limit = %u", history_limit);
@@ -818,10 +815,11 @@ void controller::run(int argc, char * argv[]) {
 		LOG(level::USERERROR, "Cleaning up cache failed: %s", e.what());
 		if (!silent) {
 			std::cout << _("failed: ") << e.what() << std::endl;
+			ret = EXIT_FAILURE;
 		}
 	}
 
-	utils::remove_fs_lock(lock_file);
+	return ret;
 }
 
 void controller::update_feedlist() {
@@ -1148,7 +1146,7 @@ void controller::start_reload_all_thread(std::vector<int> * indexes) {
 	t.detach();
 }
 
-void controller::version_information(const char * argv0, unsigned int level) {
+void controller::print_version_information(const char * argv0, unsigned int level) {
 	if (level<=1) {
 		std::cout << PROGRAM_NAME << " " << PROGRAM_VERSION << " - " << PROGRAM_URL << std::endl;
 		std::cout << "Copyright (C) 2006-2015 Andreas Krennmair" << std::endl;
@@ -1157,7 +1155,7 @@ void controller::version_information(const char * argv0, unsigned int level) {
 		std::cout << "Copyright (C) 2017 Newsboat contributors" << std::endl;
 		std::cout << std::endl;
 
-		std::cout << _("newsboat is free software and licensed under the MIT/X Consortium License.") << std::endl;
+		std::cout << _("newsboat is free software and licensed under the MIT License.") << std::endl;
 		std::cout << strprintf::fmt(_("Type `%s -vv' for more information."), argv0) << std::endl << std::endl;
 
 		struct utsname xuts;
@@ -1174,11 +1172,9 @@ void controller::version_information(const char * argv0, unsigned int level) {
 	} else {
 		std::cout << LICENSE_str << std::endl;
 	}
-
-	::exit(EXIT_SUCCESS);
 }
 
-void controller::usage(char * argv0) {
+void controller::print_usage(char * argv0) {
 	auto msg =
 	    strprintf::fmt(_("%s %s\nusage: %s [-i <file>|-e] [-u <urlfile>] "
 	    "[-c <cachefile>] [-x <command> ...] [-h]\n"),
@@ -1223,8 +1219,6 @@ void controller::usage(char * argv0) {
 		}
 		std::cout << a.desc << std::endl;
 	}
-
-	::exit(EXIT_FAILURE);
 }
 
 void controller::import_opml(const std::string& filename) {
@@ -1393,10 +1387,6 @@ std::shared_ptr<rss_feed> controller::get_feed_by_url(const std::string& feedurl
 	return std::shared_ptr<rss_feed>();
 }
 
-bool controller::is_valid_podcast_type(const std::string& /* mimetype */) {
-	return true;
-}
-
 void controller::enqueue_url(const std::string& url, std::shared_ptr<rss_feed> feed) {
 	bool url_found = false;
 	std::fstream f;
@@ -1535,7 +1525,7 @@ std::string controller::bookmark(
 	}
 }
 
-void controller::execute_commands(char ** argv, unsigned int i) {
+int controller::execute_commands(char ** argv, unsigned int i) {
 	if (v->formaction_stack_size() > 0)
 		v->pop_current_formaction();
 	for (; argv[i]; ++i) {
@@ -1547,9 +1537,11 @@ void controller::execute_commands(char ** argv, unsigned int i) {
 			std::cout << strprintf::fmt(_("%u unread articles"), rsscache->get_unread_count()) << std::endl;
 		} else {
 			std::cerr << strprintf::fmt(_("%s: %s: unknown command"), argv[0], argv[i]) << std::endl;
-			::std::exit(EXIT_FAILURE);
+			return EXIT_FAILURE;
 		}
 	}
+
+	return EXIT_SUCCESS;
 }
 
 std::string controller::write_temporary_item(std::shared_ptr<rss_item> item) {
@@ -1654,7 +1646,7 @@ void controller::enqueue_items(std::shared_ptr<rss_feed> feed) {
 	for (auto item : feed->items()) {
 		if (!item->enqueued() && item->enclosure_url().length() > 0) {
 			LOG(level::DEBUG, "controller::enqueue_items: enclosure_url = `%s' enclosure_type = `%s'", item->enclosure_url(), item->enclosure_type());
-			if (is_valid_podcast_type(item->enclosure_type()) && utils::is_http_url(item->enclosure_url())) {
+			if (utils::is_http_url(item->enclosure_url())) {
 				LOG(level::INFO, "controller::enqueue_items: enqueuing `%s'", item->enclosure_url());
 				enqueue_url(item->enclosure_url(), feed);
 				item->set_enqueued(true);
@@ -1773,7 +1765,16 @@ void controller::update_config() {
 	}
 
 	if (cfg.get_configvalue("error-log").length() > 0) {
-		logger::getInstance().set_errorlogfile(cfg.get_configvalue("error-log"));
+		try {
+			logger::getInstance().set_errorlogfile(cfg.get_configvalue("error-log"));
+		} catch (const exception& e) {
+			const std::string msg = strprintf::fmt(
+						"Couldn't open %s: %s",
+						cfg.get_configvalue("error-log"),
+						e.what());
+			v->show_error(msg);
+			std::cerr << msg << std::endl;
+		}
 	}
 
 }
