@@ -12,7 +12,7 @@
 #include <sstream>
 #include <algorithm>
 
-namespace newsbeuter {
+namespace newsboat {
 
 itemview_formaction::itemview_formaction(view * vv, std::shared_ptr<itemlist_formaction> il, std::string formstr)
 	: formaction(vv,formstr), show_source(false), quit(false), rxman(0), num_lines(0), itemlist(il), in_search(false) {
@@ -128,7 +128,7 @@ void itemview_formaction::prepare() {
 		unsigned int window_width = utils::to_u(widthstr, 0);
 
 		unsigned int textwidth = v->get_cfg()->get_configvalue_as_int("text-width");
-		if (textwidth == 0) {
+		if (textwidth == 0 || textwidth > window_width) {
 			textwidth = window_width;
 			if (textwidth - 5 > 0) {
 				textwidth -= 5;
