@@ -1,6 +1,6 @@
 #include <strprintf.h>
 
-using namespace newsbeuter;
+using namespace newsboat;
 
 /* Splits a printf-like format string into two parts, where first part contains
  * at most one format while the second part contains the rest of the input
