@@ -1,7 +1,7 @@
 #include <ttrss_api.h>
 #include <logger.h>
 
-namespace newsbeuter {
+namespace newsboat {
 
 ttrss_urlreader::ttrss_urlreader(const std::string& url_file, remote_api * a) : file(url_file), api(a) { }
 
