@@ -11,7 +11,6 @@
 #include <pwd.h>
 #include <libgen.h>
 #include <sys/utsname.h>
-#include <unistd.h>
 #include <sys/param.h>
 
 #include <unordered_set>
@@ -23,6 +22,7 @@
 #include <cstdlib>
 #include <cstdarg>
 #include <cstdio>
+#include <cmath>
 #include <algorithm>
 #include <regex>
 
@@ -44,7 +44,7 @@ GCRY_THREAD_OPTION_PTHREAD_IMPL;
 #include <openssl/crypto.h>
 #endif
 
-namespace newsbeuter {
+namespace newsboat {
 
 std::vector<std::string> utils::tokenize_quoted(const std::string& str, std::string delimiters) {
 	/*
@@ -242,51 +242,6 @@ std::vector<std::string> utils::tokenize_nl(const std::string& str, std::string
 	return tokens;
 }
 
-void utils::remove_fs_lock(const std::string& lock_file) {
-	LOG(level::DEBUG, "utils::remove_fs_lock: removed lockfile %s", lock_file);
-	::unlink(lock_file.c_str());
-}
-
-bool utils::try_fs_lock(const std::string& lock_file, pid_t & pid) {
-	int fd;
-	// pid == 0 indicates that something went majorly wrong during locking
-	pid = 0;
-
-	LOG(level::DEBUG, "utils::try_fs_lock: trying to lock %s", lock_file);
-
-	// first, we open (and possibly create) the lock file
-	fd = ::open(lock_file.c_str(), O_RDWR | O_CREAT, 0600);
-	if (fd < 0)
-		return false;
-
-	// then we lock it (T_LOCK returns immediately if locking is not possible)
-	if (lockf(fd, F_TLOCK, 0) == 0) {
-		std::string pidtext = std::to_string(getpid());
-		// locking successful -> truncate file and write own PID into it
-		ssize_t written = 0;
-		if (ftruncate(fd, 0) == 0) {
-			written = write(fd, pidtext.c_str(), pidtext.length());
-		}
-		bool success =
-			   (written != -1)
-			&& (static_cast<unsigned int>(written) == pidtext.length());
-		return success;
-	}
-
-	// locking was not successful -> read PID of locking process from it
-	fd = ::open(lock_file.c_str(), O_RDONLY);
-	if (fd >= 0) {
-		char buf[32];
-		int len = read(fd, buf, sizeof(buf)-1);
-		unsigned int upid = 0;
-		buf[len] = '\0';
-		sscanf(buf, "%u", &upid);
-		pid = upid;
-		close(fd);
-	}
-	return false;
-}
-
 std::string utils::translit(const std::string& tocode, const std::string& fromcode)
 {
 	std::string tlit = "//TRANSLIT";
@@ -346,7 +301,7 @@ std::string utils::convert_text(const std::string& text, const std::string& toco
 	 * of all the Unix-like systems around there, only Linux/glibc seems to
 	 * come with a SuSv3-conforming iconv implementation.
 	 */
-#if !(__linux) && !defined(__GLIBC__) && !defined(__APPLE__) \
+#if !defined(__linux__) && !defined(__GLIBC__) && !defined(__APPLE__) \
 	&& !defined(__OpenBSD__) && !defined(__FreeBSD__) && !defined(__DragonFly__)
 	const char * inbufp;
 #else
@@ -784,6 +739,64 @@ size_t utils::wcswidth_stfl(const std::wstring& str, size_t size) {
 	return width - reduce_count;
 }
 
+std::string utils::substr_with_width(
+		const std::string& str,
+		const size_t max_width)
+{
+	// Returns a longest substring fits to the given width.
+	// Returns an empty string if `str` is an empty string or `max_width` is zero,
+	//
+	// Each chararacter width is calculated with wcwidth(3). If wcwidth() returns < 1,
+	// the character width is treated as 0. A STFL tag (e.g. `<b>`, `<foobar>`, `</>`)
+	// width is treated as 0, but escaped less-than (`<>`) width is treated as 1.
+
+	if (str.empty() || max_width == 0) {
+		return std::string("");
+	}
+
+	const std::wstring wstr = utils::str2wstr(str);
+	size_t total_width = 0;
+	bool in_bracket = false;
+	std::wstring result;
+	std::wstring tagbuf;
+
+	for (auto wc : wstr) {
+		if (in_bracket) {
+			tagbuf += wc;
+			if (wc == L'>') {  // tagbuf is escaped less-than or tag
+				in_bracket = false;
+				if (tagbuf == L"<>") {
+					if (total_width + 1 > max_width) {
+						break;
+					}
+					result += L"<>";  // escaped less-than
+					tagbuf.clear();
+					total_width++;
+				} else {
+					result += tagbuf;
+					tagbuf.clear();
+				}
+			}
+		} else {
+			if (wc == L'<') {
+				in_bracket = true;
+				tagbuf += wc;
+			} else {
+				int w = wcwidth(wc);
+				if (w < 1) {
+					w = 0;
+				}
+				if (total_width + w > max_width) {
+					break;
+				}
+				total_width += w;
+				result += wc;
+			}
+		}
+	}
+	return utils::wstr2str(result);
+}
+
 std::string utils::join(const std::vector<std::string>& strings, const std::string& separator) {
 	std::string result;
 
@@ -1107,13 +1120,20 @@ int utils::run_interactively(
 }
 
 std::string utils::getcwd() {
-	char cwdtmp[MAXPATHLEN];
+	// Linux seem to have its MAX_PATH set somewhere around this value, so
+	// should be a nice default
+	std::vector<char> result(4096, '\0');
 
-	if (::getcwd(cwdtmp, sizeof(cwdtmp)) == nullptr) {
-		strncpy(cwdtmp, strerror(errno), MAXPATHLEN);
+	while (true) {
+		char* ret = ::getcwd(result.data(), result.size());
+		if (ret == nullptr && errno == ERANGE) {
+			result.resize(result.size() * 2);
+		} else {
+			break;
+		}
 	}
 
-	return std::string(cwdtmp);
+	return std::string(result.data());
 }
 
 void utils::remove_soft_hyphens(std::string& text) {
@@ -1128,6 +1148,17 @@ void utils::remove_soft_hyphens(std::string& text) {
 	}
 }
 
+bool utils::is_valid_podcast_type(const std::string& mimetype) {
+	const std::unordered_set<std::string> acceptable = {
+		"audio/mpeg",
+		"audio/mp3",
+		"audio/x-mp3",
+		"audio/ogg",
+		"application/ogg"
+	};
+	return acceptable.find(mimetype) != acceptable.end();
+}
+
 
 /*
  * See http://curl.haxx.se/libcurl/c/libcurl-tutorial.html#Multi-threading for a reason why we do this.
