@@ -4,7 +4,7 @@
 #include <configparser.h>
 #include <keymap.h>
 
-using namespace newsbeuter;
+using namespace newsboat;
 
 TEST_CASE("ConfigContainer parses test config without exceptions",
           "[configcontainer]")
@@ -12,7 +12,7 @@ TEST_CASE("ConfigContainer parses test config without exceptions",
 	configcontainer cfg;
 	configparser cfgparser;
 	cfg.register_commands(cfgparser);
-	keymap k(KM_NEWSBEUTER);
+	keymap k(KM_NEWSBOAT);
 	cfgparser.register_handler("macro", &k);
 
 	REQUIRE_NOTHROW(cfgparser.parse("data/test-config.txt"));
