@@ -3,10 +3,10 @@
 #include <keymap.h>
 #include <exceptions.h>
 
-using namespace newsbeuter;
+using namespace newsboat;
 
 TEST_CASE("get_operation()", "[keymap]") {
-	keymap k(KM_NEWSBEUTER);
+	keymap k(KM_NEWSBOAT);
 
 	REQUIRE(k.get_operation("u", "article") == OP_SHOWURLS);
 	REQUIRE(k.get_operation("X", "feedlist") == OP_NIL);
@@ -20,7 +20,7 @@ TEST_CASE("get_operation()", "[keymap]") {
 }
 
 TEST_CASE("unset_key() and set_key()", "[keymap]") {
-	keymap k(KM_NEWSBEUTER);
+	keymap k(KM_NEWSBOAT);
 
 	REQUIRE(k.get_operation("ENTER", "feedlist") == OP_OPEN);
 	REQUIRE(k.getkey(OP_OPEN, "all") == "ENTER");
@@ -38,14 +38,14 @@ TEST_CASE("unset_key() and set_key()", "[keymap]") {
 }
 
 TEST_CASE("get_opcode()", "[keymap]") {
-	keymap k(KM_NEWSBEUTER);
+	keymap k(KM_NEWSBOAT);
 
 	REQUIRE(k.get_opcode("open") == OP_OPEN);
 	REQUIRE(k.get_opcode("some-noexistent-operation") == OP_NIL);
 }
 
 TEST_CASE("getkey()", "[keymap]") {
-	keymap k(KM_NEWSBEUTER);
+	keymap k(KM_NEWSBOAT);
 
 	SECTION("Retrieves general bindings") {
 		REQUIRE(k.getkey(OP_OPEN, "all") == "ENTER");
@@ -62,7 +62,7 @@ TEST_CASE("getkey()", "[keymap]") {
 }
 
 TEST_CASE("get_key()", "[keymap]") {
-	keymap k(KM_NEWSBEUTER);
+	keymap k(KM_NEWSBOAT);
 
 	REQUIRE(k.get_key(" ") == ' ');
 	REQUIRE(k.get_key("U") == 'U');
@@ -74,7 +74,7 @@ TEST_CASE("get_key()", "[keymap]") {
 }
 
 TEST_CASE("handle_action()", "[keymap]") {
-	keymap k(KM_NEWSBEUTER);
+	keymap k(KM_NEWSBOAT);
 	std::vector<std::string> params;
 
 	SECTION("without parameters") {
