@@ -2,7 +2,7 @@
 
 #include <textformatter.h>
 
-using namespace newsbeuter;
+using namespace newsboat;
 
 TEST_CASE("lines marked as `wrappable` are wrapped to fit width",
           "[textformatter]") {
@@ -47,6 +47,40 @@ TEST_CASE("lines marked as `wrappable` are wrapped to fit width",
 	}
 }
 
+TEST_CASE("line wrapping works for non-space-separeted text",
+          "[textformatter]") {
+
+	textformatter fmt;
+
+	fmt.add_lines(
+		{
+			std::make_pair(LineType::wrappable,
+					"    つれづれなるままに、ひぐらしすずりにむかいて、")
+		});
+
+
+	SECTION("preserve indent and doesn't return broken UTF-8") {
+		const std::string expected = (
+				"    つれづれなるまま\n"
+				"    に、ひぐらしすず\n"
+				"    りにむかいて、\n");
+		REQUIRE(fmt.format_text_plain(20) == expected);
+		// +1 is not enough to store single wide-width char
+		REQUIRE(fmt.format_text_plain(20+1) == expected);
+	}
+
+	SECTION("truncate indent if given window width is too narrow") {
+		REQUIRE(fmt.format_text_plain(1) == (" \n"));
+		REQUIRE(fmt.format_text_plain(2) == ("  \n"));
+		REQUIRE(fmt.format_text_plain(3) == ("   \n"));
+	}
+
+	SECTION("discard current word if there's not enough space to put single char") {
+		REQUIRE(fmt.format_text_plain(4) == ("    \n"));
+		REQUIRE(fmt.format_text_plain(5) == ("    \n"));
+	}
+}
+
 TEST_CASE("regex manager is used by format_text_to_list if one is passed",
           "[textformatter]") {
 	textformatter fmt;
@@ -122,6 +156,22 @@ TEST_CASE("wrappable sequences longer then format width are forced-wrapped",
 	REQUIRE(fmt.format_text_plain(5, 10) == expected);
 }
 
+TEST_CASE("Lines marked as non-wrappable are always returned verbatim",
+		"[textformatter]")
+{
+	textformatter fmt;
+	fmt.add_line(LineType::wrappable, " 0123456789101112");
+	fmt.add_line(LineType::softwrappable, " 0123456789101112");
+	fmt.add_line(LineType::nonwrappable, " 0123456789101112");
+
+	const std::string expected =
+		" \n"
+		" \n"
+		" 0123456789101112\n";
+	REQUIRE(fmt.format_text_plain(1, 1) == expected);
+
+}
+
 /*
  * A simple wrapping function would simply split the line at the wrapping width.
  * This, while it technically works, misaligns the text if the line is split
@@ -136,8 +186,9 @@ TEST_CASE("wrappable sequences longer then format width are forced-wrapped",
  * second line and it would make the text look jagged with a bigger input. Thus
  * spaces at the beginning of lines after wrapping should be dropped.
  */
-TEST_CASE("textformatter: ignore whitespace that's going to be wrapped onto "
-          "the next line", "[textformatter]") {
+TEST_CASE("ignore whitespace that's going to be wrapped onto the next line",
+		"[textformatter]")
+{
 	textformatter fmt;
 	fmt.add_line(LineType::wrappable, "just a test");
 
